
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    require Test::More;
    Test::More::plan(skip_all => 'these tests are for testing by the author');
  }
}

use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006008
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
DROLSKY
DROLSKY's
Rolsky
Rolsky's
API
BER
CPAN
Fandiño
GitHub
SV
Storable
postincrement
preprocessing
uint
wishlist
Salvador
Fandino
sfandino
Dave
autarch
bulk88
David
Steinbrunner
dsteinbrunner
Dylan
Cali
calid1984
lib
Math
Int64
die_on_overflow
native_if_available
UInt64
